% This is a very basic demo script that just shows how to run a model.  It uses
% a small prebuilt network having two layers: an input layer with predefined
% spike rates and a single Golomb-Amitai layer.

% Load model and input data.
d = load(fullfile(fileparts(mfilename('fullpath')), 'hhpkg_demo_data'));
m     = d.m;     % A prebuilt network model structure.
rates = d.rates; % Input layer spike rates (per ms).
clear d;

% Generate spikes from rates.
stimDT = 1e-3;
spikeTimes = cns_makespikes(rates, m.dt, stimDT);

% Load spikes into layer 1 of the model.
m.layers{1}.t_next = shiftdim(spikeTimes(1, :, :), 1);
m.layers{1}.t_all  = spikeTimes(2 : end, :, :);

% Instantiate model on the GPU.
cns('init', m);

% Run the model, pulling back V_m for layer 2.
stimDur = size(rates, 1) * stimDT;
numSteps = stimDur / m.dt;
vm = cns('run', numSteps, {2, 'V_m'});

% Release GPU resources.
cns('done');

% Plot layer 2 V_m.
cns_tplot(vm, m.dt);
xlabel('time (s)');
ylabel('membrane voltage');